==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'articolelor viitoare (nu afectează baza de date).',
	'bouton_radio_articles_tous' => 'toate articolelor fără excepţie.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'toate articolelor cu excepţia celor cu forum dezactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Înregistrare obligatorie (utilizatorii trebuie să se înregistreze furnizând adresa lor de email înainte de propune contribuţii).',
	'bouton_radio_moderation_priori' => 'Moderare à priori (contribuţiile nu sunt afişate decât după validarea lor de către un administrator).', # MODIF
	'bouton_radio_modere_abonnement' => 'cu abonament',
	'bouton_radio_modere_posteriori' => 'moderare ulterioară', # MODIF
	'bouton_radio_modere_priori' => 'moderare à priori', # MODIF
	'bouton_radio_publication_immediate' => 'Publicarea imediată a mesajelor
 (contribuţiile sunt afişate imediat, un administrator poate
 să le şteargă ulterior).',

	// D
	'documents_interdits_forum' => 'Documentele sunt interzise în forum',

	// F
	'form_pet_message_commentaire' => 'Un mesaj, un comentariu ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nu mai aveţi acces la aceste forum-uri.',
	'forum_attention_dix_caracteres' => '<b>Atenţie !</b> mesajul dumneavoastră trebuie să conţină cel puţin  zece caractere.',
	'forum_attention_trois_caracteres' => '<b>Atenţie !</b> titlul dumneavoastră trebuie să conţină cel puţin trei caractere.',
	'forum_attention_trop_caracteres' => '<b>Atenţie !</b> mesajul dumneavoastră este prea lung(@compte@ caractere) : pentru a-l putea înregistra, mesajul nu trebuie să depăşească @max@ caractere.', # MODIF
	'forum_avez_selectionne' => 'Aţi selecţionat :',
	'forum_cliquer_retour' => 'Faceţi click <a href=\'@retour_forum@\'>aici</a> pentru a continua.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Acest forum este moderat: contribuţia dumneavoastră nu va apare decât după ce va fi validată de către un administrator al site-ului.', # MODIF
	'forum_lien_hyper' => '<b>Legătură hipertext</b> (opţională)', # MODIF
	'forum_message_definitif' => 'Mesaj definitiv : trimiteţi către site',
	'forum_message_trop_long' => 'Mesajul dumneavoastră este prea lung. Puteți folosi maxim 20.000 caractere.', # MODIF
	'forum_ne_repondez_pas' => 'Nu răspundeţi acestui email, ci direct pe forum la adresa următoare :', # MODIF
	'forum_page_url' => '(Dacă mesajul se referă la un articol publicat pe Web sau la o pagină cu informaţii suplimentare, indicaţi mai jos titlul şi adresa URL a paginii.)',
	'forum_poste_par' => 'Mesaj publicat de @parauteur@ ca răspuns la articolul « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Cine sunteţi dumneavoastră ?</b> (opţional)', # MODIF
	'forum_texte' => 'Textul mesajului dumneavoastră :', # MODIF
	'forum_titre' => 'Titlu :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validaţi această alegere',
	'forum_voir_avant' => 'Vedeţi acest mesaj înainte de a-l trimite', # MODIF
	'forum_votre_email' => 'Adresa dumneavoastră de email :', # MODIF
	'forum_votre_nom' => 'Numele dumneavoastră (sau pseudonimul) :', # MODIF
	'forum_vous_enregistrer' => 'Pentru a participa
  la acest forum, trebuie să vă înregistraţi în prealabil. Vă rugăm să furnizaţi identificatorul personal care v-a fost furnizat.
  Dacă nu sunteţi deja înregistrat, va trebui',
	'forum_vous_inscrire' => ' să vă înscrieţi.',

	// I
	'icone_poster_message' => 'Trimiteţi un mesaj',
	'icone_suivi_forum' => 'Urmăriţi forum-ul public : @nb_forums@ contribuții',
	'icone_suivi_forums' => 'Administrare forumuri',
	'icone_supprimer_message' => 'Suprimaţi acest mesaj',
	'icone_valider_message' => 'Validaţi acest mesaj',
	'info_activer_forum_public' => '<i>Pentru a activa forum-urile publice, vă rugăm să alegeţi modul
 lor de operare implicit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicaţi această alegere de moderare :',
	'info_config_forums_prive' => 'În cadrul spaţiului privat al site-ului, puteţi activa mai multe tipuri de forumuri :', # MODIF
	'info_config_forums_prive_admin' => 'Un forum rezervat administratorilor site-ului :',
	'info_config_forums_prive_global' => 'Un forum global, deschis la toţi redactorii :',
	'info_config_forums_prive_objets' => 'Un forum ataşat fiecărui articol, ştire, site referenţiat, etc. :',
	'info_desactiver_forum_public' => 'Dezactivaţi folosirea forum-urilor publice. Forum-urile pot fi activate pentru fiecare articol în parte, după caz; vor rămâne deactivate pentru rubrici, ştiri, ş.a.m.d.',
	'info_envoi_forum' => 'Trimitere forum-urile la autorii articolelor',
	'info_fonctionnement_forum' => 'Funcţionarea forum-ului :',
	'info_gauche_suivi_forum_2' => '<i>Pagina de urmarire a forum-urilor</i> este o unealtă de gestiune a site-ului (nu un spaţiu de discuţii sau de redactare). Această pagină afişează toate contribuţiile la forum-urile site-ului, atât cel public cât şi cel privat, şi vă permite să gestionaţi aceste contribuţii.', # MODIF
	'info_liens_syndiques_3' => 'forum-uri',
	'info_liens_syndiques_4' => 'sunt',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'este',
	'info_liens_syndiques_7' => ' în aşteptarea validării',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modul implicit de funcţionare a forum-urilor publice',
	'info_option_email' => 'Atunci când un vizitator trimite un mesaj nou într-un forum
  asociat unui articol, autorii articolului pot fi
  preveniţi de acest mesaj printr-un email. Indicaţi pentru fiecare tip de forum dacă această opţiune este utilizabilă.',
	'info_pas_de_forum' => 'fără forum',
	'info_question_visiteur_ajout_document_forum' => 'Dacă dorii s autorizai vizitatorii să ataşeze documente (imagini, sunete, etc.) la mesajele din forum-uri, indicai mai jos lista de extensii de documente autorizate pentru forum-uri  (de exemplu: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Dacă doriţi să autorizaţi toate tipurile de documente considerate ca sigure de către SPIP, puneţi o steluţă. Pentru a nu autoriza nimic, lasaţi selecţia goală.', # MODIF
	'item_activer_forum_administrateur' => 'Activaţi forum-ul administratorilor',
	'item_config_forums_prive_global' => 'Activaţi forum-ul redactorilor',
	'item_config_forums_prive_objets' => 'Activaţi aceste forum-uri',
	'item_desactiver_forum_administrateur' => 'Dezactivaţi forum-ul administratorilor',
	'item_non_config_forums_prive_global' => 'Dezactivaţi forum-ul redactorilor',
	'item_non_config_forums_prive_objets' => 'Dezactivaţi aceste forum-uri',

	// L
	'lien_reponse_article' => 'Răspuns la articol',
	'lien_reponse_breve_2' => 'Răspuns la ştire',
	'lien_reponse_rubrique' => 'Răspuns la rubrica',
	'lien_reponse_site_reference' => 'Răspuns la site-ul referenţiat :', # MODIF

	// O
	'onglet_messages_internes' => 'Mesaje interne',
	'onglet_messages_publics' => 'Mesaje publice',
	'onglet_messages_vide' => 'Mesaje fără text',

	// R
	'repondre_message' => 'Răspundeţi la acest mesaj',

	// S
	'statut_original' => 'original',

	// T
	'text_article_propose_publication_forum' => 'Nu ezitaţi să ne spuneţi părerea dumneavoastră cu ajutorul forum-ului ataşat acestui articol (în josul paginii).',
	'texte_en_cours_validation_forum' => 'Nu ezitaţi să ne comunicaţi părerea dumneavoastră cu ajutorul forum-urilor ataşate.',
	'titre_cadre_forum_administrateur' => 'Forum-ul privat al administratorilor',
	'titre_cadre_forum_interne' => 'Forum intern',
	'titre_config_forums_prive' => 'Forum-uri în spaţiul privat',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Urmărirea forum-urilor',
	'titre_page_forum_suivi' => 'Urmărirea forum-urilor',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'articolelor viitoare (nu afectează baza de date).',
	'bouton_radio_articles_tous' => 'toate articolelor fără excepţie.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'toate articolelor cu excepţia celor cu forum dezactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Înregistrare obligatorie (utilizatorii trebuie să se înregistreze furnizând adresa lor de email înainte de propune contribuţii).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderare à priori (contribuţiile nu sunt afişate decât după validarea lor de către un administrator).', # MODIF
	'bouton_radio_modere_abonnement' => 'cu abonament',
	'bouton_radio_modere_posteriori' => 'moderare ulterioară', # MODIF
	'bouton_radio_modere_priori' => 'moderare à priori', # MODIF
	'bouton_radio_publication_immediate' => 'Publicarea imediată a mesajelor
 (contribuţiile sunt afişate imediat, un administrator poate
 să le şteargă ulterior).', # MODIF

	// D
	'documents_interdits_forum' => 'Documentele sunt interzise în forum',

	// F
	'form_pet_message_commentaire' => 'Un mesaj, un comentariu ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Nu mai aveţi acces la aceste forum-uri.',
	'forum_attention_dix_caracteres' => '<b>Atenţie !</b> mesajul dumneavoastră trebuie să conţină cel puţin  zece caractere.',
	'forum_attention_trois_caracteres' => '<b>Atenţie !</b> titlul dumneavoastră trebuie să conţină cel puţin trei caractere.',
	'forum_attention_trop_caracteres' => '<b>Atenţie !</b> mesajul dumneavoastră este prea lung(@compte@ caractere) : pentru a-l putea înregistra, mesajul nu trebuie să depăşească @max@ caractere.', # MODIF
	'forum_avez_selectionne' => 'Aţi selecţionat :',
	'forum_cliquer_retour' => 'Faceţi click <a href=\'@retour_forum@\'>aici</a> pentru a continua.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Acest forum este moderat: contribuţia dumneavoastră nu va apare decât după ce va fi validată de către un administrator al site-ului.', # MODIF
	'forum_lien_hyper' => '<b>Legătură hipertext</b> (opţională)', # MODIF
	'forum_message_definitif' => 'Mesaj definitiv : trimiteţi către site',
	'forum_message_trop_long' => 'Mesajul dumneavoastră este prea lung. Puteți folosi maxim 20.000 caractere.', # MODIF
	'forum_ne_repondez_pas' => 'Nu răspundeţi acestui email, ci direct pe forum la adresa următoare :', # MODIF
	'forum_page_url' => '(Dacă mesajul se referă la un articol publicat pe Web sau la o pagină cu informaţii suplimentare, indicaţi mai jos titlul şi adresa URL a paginii.)',
	'forum_poste_par' => 'Mesaj publicat de @parauteur@ ca răspuns la articolul « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Cine sunteţi dumneavoastră ?</b> (opţional)', # MODIF
	'forum_texte' => 'Textul mesajului dumneavoastră :', # MODIF
	'forum_titre' => 'Titlu :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validaţi această alegere',
	'forum_voir_avant' => 'Vedeţi acest mesaj înainte de a-l trimite', # MODIF
	'forum_votre_email' => 'Adresa dumneavoastră de email :', # MODIF
	'forum_votre_nom' => 'Numele dumneavoastră (sau pseudonimul) :', # MODIF
	'forum_vous_enregistrer' => 'Pentru a participa
  la acest forum, trebuie să vă înregistraţi în prealabil. Vă rugăm să furnizaţi identificatorul personal care v-a fost furnizat.
  Dacă nu sunteţi deja înregistrat, va trebui',
	'forum_vous_inscrire' => ' să vă înscrieţi.',

	// I
	'icone_poster_message' => 'Trimiteţi un mesaj',
	'icone_suivi_forum' => 'Urmăriţi forum-ul public : @nb_forums@ contribuții',
	'icone_suivi_forums' => 'Administrare forumuri',
	'icone_supprimer_message' => 'Suprimaţi acest mesaj',
	'icone_valider_message' => 'Validaţi acest mesaj',
	'info_activer_forum_public' => '<i>Pentru a activa forum-urile publice, vă rugăm să alegeţi modul
 lor de operare implicit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicaţi această alegere de moderare :',
	'info_config_forums_prive' => 'În cadrul spaţiului privat al site-ului, puteţi activa mai multe tipuri de forumuri :', # MODIF
	'info_config_forums_prive_admin' => 'Un forum rezervat administratorilor site-ului :', # MODIF
	'info_config_forums_prive_global' => 'Un forum global, deschis la toţi redactorii :', # MODIF
	'info_config_forums_prive_objets' => 'Un forum ataşat fiecărui articol, ştire, site referenţiat, etc. :',
	'info_desactiver_forum_public' => 'Dezactivaţi folosirea forum-urilor publice. Forum-urile pot fi activate pentru fiecare articol în parte, după caz; vor rămâne deactivate pentru rubrici, ştiri, ş.a.m.d.',
	'info_envoi_forum' => 'Trimitere forum-urile la autorii articolelor', # MODIF
	'info_fonctionnement_forum' => 'Funcţionarea forum-ului :',
	'info_gauche_suivi_forum_2' => '<i>Pagina de urmarire a forum-urilor</i> este o unealtă de gestiune a site-ului (nu un spaţiu de discuţii sau de redactare). Această pagină afişează toate contribuţiile la forum-urile site-ului, atât cel public cât şi cel privat, şi vă permite să gestionaţi aceste contribuţii.', # MODIF
	'info_liens_syndiques_3' => 'forum-uri',
	'info_liens_syndiques_4' => 'sunt',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'este',
	'info_liens_syndiques_7' => ' în aşteptarea validării',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modul implicit de funcţionare a forum-urilor publice',
	'info_option_email' => 'Atunci când un vizitator trimite un mesaj nou într-un forum
  asociat unui articol, autorii articolului pot fi
  preveniţi de acest mesaj printr-un email. Indicaţi pentru fiecare tip de forum dacă această opţiune este utilizabilă.', # MODIF
	'info_pas_de_forum' => 'fără forum',
	'info_question_visiteur_ajout_document_forum' => 'Dacă dorii s autorizai vizitatorii să ataşeze documente (imagini, sunete, etc.) la mesajele din forum-uri, indicai mai jos lista de extensii de documente autorizate pentru forum-uri  (de exemplu: gif, jpg, png, mp3).', # MODIF
	'info_question_visiteur_ajout_document_forum_format' => 'Dacă doriţi să autorizaţi toate tipurile de documente considerate ca sigure de către SPIP, puneţi o steluţă. Pentru a nu autoriza nimic, lasaţi selecţia goală.', # MODIF
	'item_activer_forum_administrateur' => 'Activaţi forum-ul administratorilor', # MODIF
	'item_config_forums_prive_global' => 'Activaţi forum-ul redactorilor', # MODIF
	'item_config_forums_prive_objets' => 'Activaţi aceste forum-uri',
	'item_desactiver_forum_administrateur' => 'Dezactivaţi forum-ul administratorilor', # MODIF
	'item_non_config_forums_prive_global' => 'Dezactivaţi forum-ul redactorilor', # MODIF
	'item_non_config_forums_prive_objets' => 'Dezactivaţi aceste forum-uri',

	// L
	'lien_reponse_article' => 'Răspuns la articol',
	'lien_reponse_breve_2' => 'Răspuns la ştire',
	'lien_reponse_rubrique' => 'Răspuns la rubrica',
	'lien_reponse_site_reference' => 'Răspuns la site-ul referenţiat :', # MODIF

	// O
	'onglet_messages_internes' => 'Mesaje interne',
	'onglet_messages_publics' => 'Mesaje publice',
	'onglet_messages_vide' => 'Mesaje fără text',

	// R
	'repondre_message' => 'Răspundeţi la acest mesaj',

	// S
	'statut_original' => 'original',

	// T
	'text_article_propose_publication_forum' => 'Nu ezitaţi să ne spuneţi părerea dumneavoastră cu ajutorul forum-ului ataşat acestui articol (în josul paginii).',
	'texte_en_cours_validation_forum' => 'Nu ezitaţi să ne comunicaţi părerea dumneavoastră cu ajutorul forum-urilor ataşate.',
	'titre_cadre_forum_administrateur' => 'Forum-ul privat al administratorilor', # MODIF
	'titre_cadre_forum_interne' => 'Forum intern',
	'titre_config_forums_prive' => 'Forum-uri în spaţiul privat',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Urmărirea forum-urilor',
	'titre_page_forum_suivi' => 'Urmărirea forum-urilor',
];
